\name{plot.gff}
\alias{plot.gff}
\alias{gff3Plotter}
\title{Plots Formatted Tiling Array Data on Genomic Layout}
\description{
   Plots formatted tiling array data as well as data of further experiments on the genomic layout.
}
\usage{
plot.gff(x, ...)
}
\arguments{
  \item{x}{A list of data as obtained from a call to \code{\link{read.gff}}}
  \item{\dots}{Further arguments as listed below...}
}
\details{
  \item{xrange}{Genomic range to plot [necessary]}
  \item{coco.tresholds}{A named numeric vector of tresholds for tiling array experiments to define color coding. Names of elements define which tiling array experiments will be plotted and in which order. [necessary if tiling array experiments are to be plotted]}
  \item{expro.tresholds}{A named numeric vector of tresholds for further experiments to define color coding. Names of elements define which experiments will be plotted and in which order. [necessary if further experiments are to be plotted]}
  \item{par.devstage}{A character vector of development stages to match genomic data with. Coloring of genes will depend on the presence of the development stage information for a particular gene that matches some/any element in this argument. If omitted gene coloring will be based on the presence of anatomy information only.}
  \item{par.anatomy}{A character vector of anatomies to match genomic data with. Coloring of genes will depend on the presence of anatomy information for a particular gene that matches any element in this argument. UNUSED AT THE MOMENT: matches are made against \code{muscle} only.}
  \item{h}{A numeric vector specifiying heights of different plot elements along the vertical axis - arbitrary unit - relative values. Can be omitted, default value is automatically retrieved by a call to \code{def.h()}}
  \item{nlevels}{A single numeric value defining in how many layers tiling array experiments are to be displayed. Default 8.}
  \item{coco.ramp}{A single logical value specifying if tiling array data color coding should be made using a color ramp function. Otherwise fixed colors are used}
}
\note{
The graphical output is produced to the default device. If output to a graphic file or any other device is required, a corresponding device must be opened prior to a call to this function and closed afterwards.
}
\value{
   \code{invisible(NULL)}
}
\author{Oleg Sklyar, email:\email{osklyar@ebi.ac.uk}}
\seealso{
   \code{\link{read.gff}}, \code{\link{plot.gff.toFile}}}
}
\examples{
   # getting data file name
   dataDir = system.file("extData", package = "gff3Plotter")
   gff3File = paste(dataDir, "test.gff3", sep = "/")

   # reading the input data file
   data = read.gff(gff3File)
   xrange = c(50000, 200000)
   coco.tresholds = 0.4
   names(coco.tresholds) = "Twist"
   expro.tresholds = c(0.2, 0.5, 0.1)
   names(expro.tresholds) = c("expDmf2", "expLmd", "expTwist")
   stages = c("stage13", "stage14", "stage15", "stage16")
   anatomy = "muscle"
   plot.gff(data, xrange, coco.tresholds, expro.tresholds, stages, anatomy)
   #plot.gff.toFile(data, "test.jpg", xrange = xrange, coco.tresholds = coco.tresholds, expro.tresholds = expro.tresholds, par.devstage = stages, par.anatomy = anatomy)
}
\keyword{hplot}
