\name{plot.gff.toFile}
\alias{plot.gff.toFile}
\title{Plots Formatted Tiling Array Data to a PNG or JPG File}
\description{
   Redirects output of \code{\link{plot.gff}} a PNG or a JPG file. Internally executes \code{\link{plot.gff}} passing all \dots arguments.
}
\usage{
plot.gff.toFile(x, file, type = "jpg", width = 1024, height = 768, use.GDD = FALSE, ...)
}
\arguments{
  \item{x}{A list of data as retrieved by a call to \code{\link{read.gff}}. Same as for \code{\link{plot.gff}}}
  \item{file}{A single character value for an output file name with a corresponding extension}
  \item{type}{A single character value for the type of graphic format \code{jpg} (default) or \code{png}}
  \item{width}{A single numeric value for the image width in pixels}
  \item{height}{A single numeric value for the image height in pixels}
  \item{use.GDD}{A logical value specifying if GDD device (\pkg{GDD} R package and \code{gd} library are required) is to be used, otherwise the default or X11 (in Linux) device is used. Might be required for command line calls to this routine in versions of R prior to 2.1 where X11 could not be activated in command line mode.}
  \item{\dots}{All arguments necessary for \code{\link{plot.gff}}}
}
\value{
   \code{invisible(NULL)}
}
\author{Oleg Sklyar, email:\email{osklyar@ebi.ac.uk}}
\seealso{
   \code{\link{read.gff}}, \code{\link{plot.gff}}}
}
\examples{
   # getting data file name
   dataDir = system.file("extData", package = "gff3Plotter")
   gff3File = paste(dataDir, "test.gff3", sep = "/")

   # reading the input data file
   data = read.gff(gff3File)
   xrange = c(50000, 200000)
   coco.tresholds = 0.4
   names(coco.tresholds) = "Twist"
   expro.tresholds = c(0.2, 0.5, 0.1)
   names(expro.tresholds) = c("expDmf2", "expLmd", "expTwist")
   stages = c("stage13", "stage14", "stage15", "stage16")
   anatomy = "muscle"
   #plot.gff(data, xrange, coco.tresholds, expro.tresholds, stages, anatomy)
   plot.gff.toFile(data, "test.jpg", xrange = xrange, coco.tresholds = coco.tresholds, expro.tresholds = expro.tresholds, par.devstage = stages, par.anatomy = anatomy)
}
\keyword{hplot}
\keyword{file}
