\name{read.gff}
\alias{read.gff}
\title{Reads and Parses GFF3 Data Files of Tiling Array Experiments}
\description{
Reads and parses GFF3 data files of tiling array experiments to enable further data processing and plotting.
}
\usage{
read.gff(fileName, keepTypes = gffTypes)
}
\arguments{
  \item{fileName}{A single character value for a GFF3 file to load.}
  \item{keepTypes}{A vector of strings defining which GFF3 fields should be preserved in the return value: default value is defined by \code{gffTypes <- c("gene", "exon", "insitu", "regulatory_region", "genomic_DNA", "expro")}}
}
\value{
   A list of \code{data.frame}-s for basic fields \code{$gene}, \code{$exon}, \code{$insitu}, \code{$genomic_DNA} and \code{$expro}.
}
\details{
   The return value is split into a list by the TYPE field of GFF3 input file. Values of TYPE that are not in \code{keepTypes} are removed. For all elements ATTRIBUTES field will be parced and additional columns will be added (e.g. \code{ID} and \code{Name} for genes). Finally the ATTRIBUTES field will be removed. Types \code{expro} and \code{genomic_DNA} are aplit to further lists of experiments based on \code{expName} attribute, which is attached as a column to these data. Values START, END, and STRAND of types \code{expro} and \code{insitu} are updated from corresponding genes.
}
\author{Oleg Sklyar, email:\email{osklyar@ebi.ac.uk}}
\seealso{
   \code{\link{plot.gff}}, \code{\link{plot.gff.toFile}}, \code{\link{getAttr}}
}
\examples{
   # getting data file name
   dataDir = system.file("extData", package = "gff3Plotter")
   gff3File = paste(dataDir, "test.gff3", sep = "/")

   # running example
   data = read.gff(gff3File)
   xrange = c(100000, 200000)
   subset = gffGetSubset(data, xrange)
}
\keyword{file}
